pub struct BandStatus {Show 23 fields
pub carves_total: i64,
pub conditions: Vec<Condition>,
pub conflict_manager: String,
pub conflicts_total: i64,
pub cooldown_remaining_seconds: i64,
pub current_limit: String,
pub deferrals_total: i64,
pub edge_tier: String,
pub effective_dry_run: bool,
pub effective_policy: String,
pub freshness_seconds: i64,
pub history: Vec<TrendSample>,
pub last_action_class: String,
pub last_change_epoch: i64,
pub last_decision: String,
pub last_util: String,
pub observed_capacity: i64,
pub observed_cost_remaining_cents: i64,
pub observed_env_id: String,
pub observed_generation: i64,
pub observed_used: i64,
pub observed_util: f64,
pub phase: String,
}Fields
carves_total: i64conditions: Vec<Condition>conflict_manager: Stringconflicts_total: i64cooldown_remaining_seconds: i64current_limit: Stringdeferrals_total: i64edge_tier: Stringeffective_dry_run: booleffective_policy: Stringfreshness_seconds: i64history: Vec<TrendSample>last_action_class: Stringlast_change_epoch: i64last_decision: Stringlast_util: Stringobserved_capacity: i64observed_cost_remaining_cents: i64observed_env_id: Stringobserved_generation: i64observed_used: i64observed_util: f64phase: StringTrait Implementations
Sourceimpl Clone for BandStatus
impl Clone for BandStatus
Sourcefn clone(&self) -> BandStatus
fn clone(&self) -> BandStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BandStatus
impl Debug for BandStatus
Sourceimpl Default for BandStatus
impl Default for BandStatus
impl<'de> Deserialize<'de> for BandStatus
impl<'de> Deserialize<'de> for BandStatus
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for BandStatus
impl Message for BandStatus
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BandStatus
impl PartialEq for BandStatus
impl Serialize for BandStatus
impl Serialize for BandStatus
impl StructuralPartialEq for BandStatus