pub struct BandSpec {Show 16 fields
pub ceiling: Option<String>,
pub cooldown_seconds: Option<i64>,
pub disruption_policy: Option<String>,
pub dry_run: Option<bool>,
pub floor: Option<String>,
pub force_limit: Option<String>,
pub force_limit_expiry: Option<String>,
pub grow_above: Option<f64>,
pub grow_factor: Option<f64>,
pub max_staleness_seconds: Option<i64>,
pub setpoint: Option<f64>,
pub shrink_below: Option<f64>,
pub shrink_factor: Option<f64>,
pub suspend: Option<bool>,
pub target_ref: Option<TargetRef>,
pub write_intent: Option<WriteIntent>,
}Fields
ceiling: Option<String>cooldown_seconds: Option<i64>disruption_policy: Option<String>dry_run: Option<bool>floor: Option<String>force_limit: Option<String>force_limit_expiry: Option<String>grow_above: Option<f64>grow_factor: Option<f64>max_staleness_seconds: Option<i64>setpoint: Option<f64>shrink_below: Option<f64>shrink_factor: Option<f64>suspend: Option<bool>target_ref: Option<TargetRef>write_intent: Option<WriteIntent>THE authorization gate, on every band kind. Added 2026-07-26: gRPC could previously set only dry_run, which is inert on eight of the ten kinds, so this surface had no way to hold or release a band at all.
Implementations
Sourceimpl BandSpec
impl BandSpec
Sourcepub fn ceiling(&self) -> &str
pub fn ceiling(&self) -> &str
Returns the value of ceiling, or the default value if ceiling is unset.
Sourcepub fn cooldown_seconds(&self) -> i64
pub fn cooldown_seconds(&self) -> i64
Returns the value of cooldown_seconds, or the default value if cooldown_seconds is unset.
Sourcepub fn disruption_policy(&self) -> &str
pub fn disruption_policy(&self) -> &str
Returns the value of disruption_policy, or the default value if disruption_policy is unset.
Sourcepub fn dry_run(&self) -> bool
pub fn dry_run(&self) -> bool
Returns the value of dry_run, or the default value if dry_run is unset.
Sourcepub fn floor(&self) -> &str
pub fn floor(&self) -> &str
Returns the value of floor, or the default value if floor is unset.
Sourcepub fn force_limit(&self) -> &str
pub fn force_limit(&self) -> &str
Returns the value of force_limit, or the default value if force_limit is unset.
Sourcepub fn force_limit_expiry(&self) -> &str
pub fn force_limit_expiry(&self) -> &str
Returns the value of force_limit_expiry, or the default value if force_limit_expiry is unset.
Sourcepub fn grow_above(&self) -> f64
pub fn grow_above(&self) -> f64
Returns the value of grow_above, or the default value if grow_above is unset.
Sourcepub fn grow_factor(&self) -> f64
pub fn grow_factor(&self) -> f64
Returns the value of grow_factor, or the default value if grow_factor is unset.
Sourcepub fn max_staleness_seconds(&self) -> i64
pub fn max_staleness_seconds(&self) -> i64
Returns the value of max_staleness_seconds, or the default value if max_staleness_seconds is unset.
Sourcepub fn setpoint(&self) -> f64
pub fn setpoint(&self) -> f64
Returns the value of setpoint, or the default value if setpoint is unset.
Sourcepub fn shrink_below(&self) -> f64
pub fn shrink_below(&self) -> f64
Returns the value of shrink_below, or the default value if shrink_below is unset.
Sourcepub fn shrink_factor(&self) -> f64
pub fn shrink_factor(&self) -> f64
Returns the value of shrink_factor, or the default value if shrink_factor is unset.